"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScreencastFrameCollector = void 0;
const tslib_1 = require("tslib");
const debug_1 = require("debug");
const events_1 = require("events");
const utils_1 = require("./utils");
const debug = debug_1.default('pw-video:ScreencastFrameCollector');
class ScreencastFrameCollector extends events_1.EventEmitter {
    constructor(page) {
        super();
        this._stopped = false;
        this._page = page;
    }
    static create(page) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            utils_1.ensurePageType(page);
            const collector = new ScreencastFrameCollector(page);
            yield collector._buildClient();
            collector._listenForFrames();
            return collector;
        });
    }
    _buildClient() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const context = this._page.context();
            this._client = yield context.newCDPSession(this._page);
        });
    }
    _listenForFrames() {
        this._client.on('Page.screencastFrame', (payload) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            debug(`received frame with timestamp ${payload.metadata.timestamp}`);
            const ackPromise = this._client.send('Page.screencastFrameAck', {
                sessionId: payload.sessionId,
            });
            if (!payload.metadata.timestamp) {
                debug('skip frame without timestamp');
                return;
            }
            this.emit('screencastframe', {
                data: Buffer.from(payload.data, 'base64'),
                received: Date.now(),
                timestamp: payload.metadata.timestamp,
            });
            try {
                yield ackPromise;
            }
            catch (e) {
                debug('error sending screencastFrameAck %j', e.message);
            }
        }));
    }
    start() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            debug('start');
            yield this._client.send('Page.startScreencast', {
                everyNthFrame: 1,
            });
        });
    }
    stop() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (this._stopped)
                return;
            debug('stopping');
            this._stopped = true;
            yield new Promise((resolve) => setTimeout(resolve, 1000));
            try {
                debug('detaching client');
                yield this._client.detach();
            }
            catch (e) {
                debug('error detaching client', e.message);
            }
            debug('stopped');
        });
    }
}
exports.ScreencastFrameCollector = ScreencastFrameCollector;
//# sourceMappingURL=ScreencastFrameCollector.js.map