"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SortedFrameQueue = void 0;
const debug_1 = require("debug");
const events_1 = require("events");
const debug = debug_1.default('pw-video:SortedFrameQueue');
class SortedFrameQueue extends events_1.EventEmitter {
    constructor(size) {
        super();
        this._frames = [];
        this._size = 40;
        if (size) {
            this._size = size;
        }
    }
    _findInsertionIndex(timestamp) {
        if (this._frames.length === 0) {
            return 0;
        }
        let i;
        let frame;
        for (i = this._frames.length - 1; i >= 0; i--) {
            frame = this._frames[i];
            if (timestamp > frame.timestamp) {
                break;
            }
        }
        return i + 1;
    }
    _emitFrames(frames) {
        debug(`emitting ${frames.length} frames`);
        this.emit('sortedframes', frames);
    }
    insert(frame) {
        if (this._frames.length === this._size) {
            const numberOfFramesToSplice = Math.floor(this._size / 2);
            const framesToProcess = this._frames.splice(0, numberOfFramesToSplice);
            this._emitFrames(framesToProcess);
        }
        const insertionIndex = this._findInsertionIndex(frame.timestamp);
        if (insertionIndex === this._frames.length) {
            debug(`inserting frame into queue at end: ${frame.timestamp}`);
            this._frames.push(frame);
        }
        else {
            debug(`inserting frame into queue at index ${insertionIndex}: ${frame.timestamp}`);
            this._frames.splice(insertionIndex, 0, frame);
        }
    }
    drain() {
        debug('draining queue');
        this._emitFrames(this._frames);
        this._frames = [];
    }
}
exports.SortedFrameQueue = SortedFrameQueue;
//# sourceMappingURL=SortedFrameQueue.js.map